==> unit-1.1.17-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTaskPlaceLineTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTaskPlaceLineTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _78_1_0414972135 _78_1_0414972135;
	public TaskPlaceLineTemplate._78_1_0414972135. Label label;
	public TaskPlaceLineTemplate._78_1_0414972135. TimeoutMessage timeoutMessage;
	public LoadingStops loadingStops;
	public TaskPlaceLineTemplate.LoadingStops. _81_22_1339785223 _81_22_1339785223;
	public StopsBlock stopsBlock;
	public TaskPlaceLineTemplate.StopsBlock. Stops stops;

    public AbstractTaskPlaceLineTemplate(B box) {
        super(box);
        id("taskPlaceLineTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (_78_1_0414972135 == null) _78_1_0414972135 = register(new _78_1_0414972135(box()).<_78_1_0414972135>id("a2092247905").owner(AbstractTaskPlaceLineTemplate.this));
		if (_78_1_0414972135 != null) label = _78_1_0414972135.label;
		if (_78_1_0414972135 != null) timeoutMessage = _78_1_0414972135.timeoutMessage;
		if (loadingStops == null) loadingStops = register(new LoadingStops(box()).<LoadingStops>id("a233750819").owner(AbstractTaskPlaceLineTemplate.this));
		if (loadingStops != null) _81_22_1339785223 = loadingStops._81_22_1339785223;
		if (stopsBlock == null) stopsBlock = register(new StopsBlock(box()).<StopsBlock>id("a1700500010").owner(AbstractTaskPlaceLineTemplate.this));
		if (stopsBlock != null) stops = stopsBlock.stops;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_78_1_0414972135 != null) _78_1_0414972135.unregister();
	    if (loadingStops != null) loadingStops.unregister();
	    if (stopsBlock != null) stopsBlock.unregister();
	}

	public class _78_1_0414972135 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TaskPlaceLineTemplate._78_1_0414972135. Label label;
		public TaskPlaceLineTemplate._78_1_0414972135. TimeoutMessage timeoutMessage;

		public _78_1_0414972135(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (label == null) label = register(new Label(box()).<Label>id("a_2048818114").owner(AbstractTaskPlaceLineTemplate.this));
			if (timeoutMessage == null) timeoutMessage = register(new TimeoutMessage(box()).<TimeoutMessage>id("a_1252787876").owner(AbstractTaskPlaceLineTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (label != null) label.unregister();
			if (timeoutMessage != null) timeoutMessage.unregister();
		}

		public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public Label(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}

		public class TimeoutMessage extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public TimeoutMessage(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}

	public class LoadingStops extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TaskPlaceLineTemplate.LoadingStops. _81_22_1339785223 _81_22_1339785223;

		public LoadingStops(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_81_22_1339785223 == null) _81_22_1339785223 = register(new _81_22_1339785223(box()).<_81_22_1339785223>id("a_87150365").owner(AbstractTaskPlaceLineTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_81_22_1339785223 != null) _81_22_1339785223.unregister();
		}

		public class _81_22_1339785223 extends io.intino.alexandria.ui.displays.components.Spinner<io.intino.alexandria.ui.displays.notifiers.SpinnerNotifier, B>  {

			public _81_22_1339785223(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}

	public class StopsBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TaskPlaceLineTemplate.StopsBlock. Stops stops;

		public StopsBlock(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (stops == null) stops = register(new Stops((UnitBox)box()).<Stops>id("a1498621532").owner(AbstractTaskPlaceLineTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (stops != null) stops.unregister();
		}

		public class Stops extends io.intino.alexandria.ui.displays.components.Multiple<UnitBox,TaskPlaceLineStopTemplate, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<UnitBox,TaskPlaceLineStopTemplate, java.lang.Void> {

			public Stops(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}

			@Override
			public TaskPlaceLineStopTemplate add(java.lang.Void value) {
				TaskPlaceLineStopTemplate child = new TaskPlaceLineStopTemplate(box());
				child.id(java.util.UUID.randomUUID().toString());
				add(child, "stops");
			    notifyAdd(child);
				return child;
			}
			@Override
			public void remove(TaskPlaceLineStopTemplate child) {
				removeChild(child, "stops");
			}
			public void clear() {
			    super.clear("stops");
			}
		}
	}
}

==> unit-2.1.8-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTaskPlaceLineTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTaskPlaceLineTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _78_1_0614664671 _78_1_0614664671;
	public TaskPlaceLineTemplate._78_1_0614664671. Label label;
	public TaskPlaceLineTemplate._78_1_0614664671. TimeoutMessage timeoutMessage;
	public LoadingStops loadingStops;
	public TaskPlaceLineTemplate.LoadingStops. _81_22_1339785223 _81_22_1339785223;
	public StopsBlock stopsBlock;
	public TaskPlaceLineTemplate.StopsBlock. Stops stops;

	public AbstractTaskPlaceLineTemplate(B box) {
		super(box);
		id("taskPlaceLineTemplate");
	}

	@Override
	public void init() {
		super.init();
		if (_78_1_0614664671 == null) _78_1_0614664671 = register(new _78_1_0614664671(box()).<_78_1_0614664671>id("a_1609407488").owner(AbstractTaskPlaceLineTemplate.this));
		if (_78_1_0614664671 != null) label = _78_1_0614664671.label;
		if (_78_1_0614664671 != null) timeoutMessage = _78_1_0614664671.timeoutMessage;
		if (loadingStops == null) loadingStops = register(new LoadingStops(box()).<LoadingStops>id("a233750819").owner(AbstractTaskPlaceLineTemplate.this));
		if (loadingStops != null) _81_22_1339785223 = loadingStops._81_22_1339785223;
		if (stopsBlock == null) stopsBlock = register(new StopsBlock(box()).<StopsBlock>id("a1700500010").owner(AbstractTaskPlaceLineTemplate.this));
		if (stopsBlock != null) stops = stopsBlock.stops;
	}

	@Override
	public void remove() {
		super.remove();
		if (_78_1_0614664671 != null) _78_1_0614664671.unregister();
		if (loadingStops != null) loadingStops.unregister();
		if (stopsBlock != null) stopsBlock.unregister();
	}

	public class _78_1_0614664671 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TaskPlaceLineTemplate._78_1_0614664671. Label label;
		public TaskPlaceLineTemplate._78_1_0614664671. TimeoutMessage timeoutMessage;

		public _78_1_0614664671(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (label == null) label = register(new Label(box()).<Label>id("a_2048818114").owner(AbstractTaskPlaceLineTemplate.this));
			if (timeoutMessage == null) timeoutMessage = register(new TimeoutMessage(box()).<TimeoutMessage>id("a_1252787876").owner(AbstractTaskPlaceLineTemplate.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (label != null) label.unregister();
			if (timeoutMessage != null) timeoutMessage.unregister();
		}

		public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public Label(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}

		public class TimeoutMessage extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public TimeoutMessage(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}
	}

	public class LoadingStops extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TaskPlaceLineTemplate.LoadingStops. _81_22_1339785223 _81_22_1339785223;

		public LoadingStops(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_81_22_1339785223 == null) _81_22_1339785223 = register(new _81_22_1339785223(box()).<_81_22_1339785223>id("a_87150365").owner(AbstractTaskPlaceLineTemplate.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (_81_22_1339785223 != null) _81_22_1339785223.unregister();
		}

		public class _81_22_1339785223 extends io.intino.alexandria.ui.displays.components.Spinner<io.intino.alexandria.ui.displays.notifiers.SpinnerNotifier, B>  {

			public _81_22_1339785223(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}
	}

	public class StopsBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TaskPlaceLineTemplate.StopsBlock. Stops stops;

		public StopsBlock(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (stops == null) stops = AbstractTaskPlaceLineTemplate.this.stops = register(new Stops((UnitBox)box()).<Stops>id("a1498621532").owner(AbstractTaskPlaceLineTemplate.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (stops != null) stops.unregister();
		}

		public class Stops extends io.intino.alexandria.ui.displays.components.Multiple<UnitBox,TaskPlaceLineStopTemplate, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<UnitBox,TaskPlaceLineStopTemplate, java.lang.Void> {

			public Stops(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}

			@Override
			public TaskPlaceLineStopTemplate add(java.lang.Void value) {
				TaskPlaceLineStopTemplate child = new TaskPlaceLineStopTemplate(box());
				child.id(java.util.UUID.randomUUID().toString());
				add(child, "stops");
				notifyAdd(child);
				return child;
			}
			@Override
			public void remove(TaskPlaceLineStopTemplate child) {
				removeChild(child, "stops");
			}
			public void clear() {
				super.clear("stops");
			}
		}
	}
}
